@@ -10,27 +10,27 @@
 #' distinctiveness for a single community. Functional distinctiveness relates to
 #' the functional "originality" of a species in a community. The closer to 1 the
 #' more the species is functionally distinct from the rest of the community. See
-#' \code{\link[funrar]{distinctiveness}} function or the functional rarity
+#' [distinctiveness()] function or the functional rarity
 #' indices vignette included in the package
-#' (type \code{vignette("rarity_indices", package = "funrar")}), for more details
+#' (type `vignette("rarity_indices", package = "funrar")`), for more details
 #' on the metric.
 #'
 #' @inheritParams scarcity_com
 #'
 #' @param dist_matrix a functional distance matrix as given by
-#'    \code{compute_dist_matrix()}, with species name as row and column names
+#'    `compute_dist_matrix()`, with species name as row and column names
 #'
-#' @return the same data.frame with the additional \strong{Di} column giving
+#' @return the same data.frame with the additional **Di** column giving
 #'    functional distinctiveness values for each species
 #'
 #' @section Caution:
 #' This function is meant for internal uses mostly, thus it does not include any
 #' tests on inputs and may fail unexpectedly. Please use
-#' \code{\link[funrar]{distinctiveness_stack}} to avoid input errors.
+#' [distinctiveness_stack()] to avoid input errors.
 #'
-#' @seealso \code{\link[funrar]{scarcity_com}},
-#' \code{vignette("rarity_indices", package = "funrar")} and
-#' \code{link[funrar]{distinctiveness}} Details section for detail on the index
+#' @seealso [scarcity_com()],
+#' `vignette("rarity_indices", package = "funrar")` and
+#' [distinctiveness()] Details section for detail on the index
 #'
 #' @export
 distinctiveness_com = function(com_df, sp_col, abund = NULL, dist_matrix) {
@@ -82,22 +82,22 @@ distinctiveness_com = function(com_df, sp_col, abund = NULL, dist_matrix) {
 #' needs a species functional distances matrix. Functional distinctiveness
 #' relates to the functional "originality" of a species in a community. The
 #' closer to 1 the more the species is functionally distinct from the rest of
-#' the community. See \code{\link[funrar]{distinctiveness}} function or the
+#' the community. See [distinctiveness()] function or the
 #' functional rarity indices vignette included in the package
-#' (type \code{vignette("rarity_indices", package = "funrar")}), for more details
+#' (type `vignette("rarity_indices", package = "funrar")`), for more details
 #' on the metric.
 #'
 #' @inheritParams distinctiveness_com
 #'
 #' @param com a character vector, the column name for communities names
 #'
-#' @return the same data.frame with the additional \strong{Di} column giving
+#' @return the same data.frame with the additional **Di** column giving
 #'    functional distinctiveness values for each species
 #'
-#' @seealso \code{\link[funrar]{scarcity_stack}},
-#' \code{\link[funrar]{uniqueness_stack}},
-#' \code{\link[funrar]{restrictedness_stack}};
-#' \code{\link[funrar]{distinctiveness}} Details section for detail on the index
+#' @seealso [scarcity_stack()],
+#' [uniqueness_stack()],
+#' [restrictedness_stack()];
+#' [distinctiveness()] Details section for detail on the index
 #'
 #' @examples
 #' data("aravo", package = "ade4")
@@ -109,6 +109,7 @@ distinctiveness_com = function(com_df, sp_col, abund = NULL, dist_matrix) {
 #'
 #' # Site-species matrix converted into data.frame
 #' mat = as.matrix(aravo$spe)
+#' mat = make_relative(mat)
 #' dat = matrix_to_stack(mat, "value", "site", "species")
 #' dat$site = as.character(dat$site)
 #' dat$species = as.character(dat$species)
@@ -156,8 +157,8 @@ distinctiveness_stack = function(com_df, sp_col, com, abund = NULL,
 #'
 #' Computes functional distinctiveness from a site-species matrix (containing
 #' presence-absence or relative abundances) of species with provided functional
-#' distance matrix. The sites-species matrix should have \strong{sites} in
-#' \strong{rows} and \strong{species} in \strong{columns}, similar to
+#' distance matrix. The sites-species matrix should have **sites** in
+#' **rows** and **species** in **columns**, similar to
 #' \pkg{vegan} package defaults.
 #'
 #' @param pres_matrix a site-species matrix (presence-absence or relative
@@ -165,21 +166,21 @@ distinctiveness_stack = function(com_df, sp_col, com, abund = NULL,
 #'
 #' @param dist_matrix a species functional distance matrix
 #'
-#' @return a similar matrix from provided \code{pres_matrix} with Distinctiveness
+#' @return a similar matrix from provided `pres_matrix` with Distinctiveness
 #'    values in lieu of presences or relative abundances, species absent from
-#'    communities will have an \code{NA} value (see \code{Note} section)
+#'    communities will have an `NA` value (see `Note` section)
 #'
 #' @section Note:
-#'    Absent species should be coded by \code{0} or \code{NA} in input matrices.
+#'    Absent species should be coded by `0` or `NA` in input matrices.
 #'
 #'    When a species is alone in its community the functional distinctiveness
 #'    cannot be computed (denominator = 0 in formula), and its value is assigned
-#'    as \code{NaN}.
+#'    as `NaN`.
 #'
 #'    For speed and memory efficiency sparse matrices can be used as input of
-#'    the function using \code{as(pres_matrix, "sparseMatrix")} from the
-#'    \code{Matrix} package.
-#'    (see \code{vignette("sparse_matrices", package = "funrar")})
+#'    the function using `as(pres_matrix, "sparseMatrix")` from the
+#'    `Matrix` package.
+#'    (see `vignette("sparse_matrices", package = "funrar")`)
 #'
 #' @details
 #'    The Functional Distinctiveness of a species is the average functional
@@ -202,6 +203,9 @@ distinctiveness_stack = function(com_df, sp_col, com, abund = NULL,
 #' # Site-species matrix
 #' mat = as.matrix(aravo$spe)
 #'
+#' # Compute relative abundances
+#' mat = make_relative(mat)
+#'
 #' # Example of trait table
 #' tra = aravo$traits[, c("Height", "SLA", "N_mass")]
 #' # Distance matrix
@@ -210,6 +214,15 @@ distinctiveness_stack = function(com_df, sp_col, com, abund = NULL,
 #' di = distinctiveness(pres_matrix = mat, dist_matrix = dist_mat)
 #' di[1:5, 1:5]
 #'
+#' # Compute distinctiveness for all species in the regional pool
+#' # i.e., with all the species in all the communities
+#' # Here considering each species present evenly in the regional pool
+#' reg_pool = matrix(1, ncol = ncol(mat))
+#' colnames(reg_pool) = colnames(mat)
+#' row.names(reg_pool) = c("Regional_pool")
+#'
+#' reg_di = distinctiveness(reg_pool, dist_mat)
+#'
 #' @export
 distinctiveness = function(pres_matrix, dist_matrix) {
 
@@ -253,8 +266,8 @@ distinctiveness = function(pres_matrix, dist_matrix) {
 
   # Test if there is NaN in the table for species alone in their community
   if (any(vapply(index_matrix, function(x) is.nan(x), logical(1)))) {
-    warning(paste0("Some communities had a single species in them",
-                   "Computed value assigned to 'NaN'", sep = "\n"))
+    warning("Some communities had a single species in them\n",
+            "Computed value assigned to 'NaN'")
   }
 
 
